@@ -52,7 +52,7 @@ def createEDDM(screen, logfile, contrib, gaussdir, unres):
         else:
             return "${" + x + "}"
 
-    def createcubes(mo):       
+    def createcubes(mo):
         cube = "mo%s.cub" % getmo(mo)
         report = "echo Creating cubefile %s" % cube
         orb = mo[0] + 1
@@ -148,27 +148,43 @@ def createEDDM(screen, logfile, contrib, gaussdir, unres):
             output.write("function tran%d\n{\n" % (i+1))
             
         totalcon = sum(contrib[i])
-        for sec in logfile.etsecs[i]:
-            createcubes(sec[0])
-            createcubes(sec[1])
-            createsquares(sec[0])
-            createsquares(sec[1])
-        scale = float(contrib[i][0]) / totalcon # Should square totalcon?
-        cubman(["sc","sq%s.cub" % getmo(logfile.etsecs[i][0][0]),"y","before.cub","y",str(scale)])
-        cubman(["sc","sq%s.cub" % getmo(logfile.etsecs[i][0][1]),"y","after.cub","y",str(scale)])
-        for j in range(1, len(logfile.etsecs[i])):
-            scale = float(contrib[i][j]) / totalcon # Should square totalcon?
-            cubman(["sc","sq%s.cub" % getmo(logfile.etsecs[i][j][0]),"y","tmp.cub","y",str(scale)])
-            cubman(["a","tmp.cub","y","before.cub","y","tmp2.cub","y"])
-            output.write("%s tmp2.cub before.cub\n" % syscmd[MOVE])
-            cubman(["sc","sq%s.cub" % getmo(logfile.etsecs[i][j][1]),"y","after.cub","y",str(scale)])
-            cubman(["a","tmp.cub","y","after.cub","y","tmp2.cub","y"])
-            output.write("%s tmp2.cub after.cub\n" % syscmd[MOVE])
-        output.write("%s tmp.cub\n" % syscmd[DELETE])
+        scales = [x / float(totalcon) for x in contrib[i]]
+        minimum_scale = 0 # Don't include contributions that don't contribute!
 
-        cubman(["su","before.cub","y","after.cub","y",
-                "trans%d.cub" % (i+1,),"y"])
-        # output.write("del before.cub\ndel after.cub\n")
+        # Create any necessary cube and squared files
+        alreadydone = set()
+        for sec, scale in zip(logfile.etsecs[i], scales):
+            if scale > minimum_scale:
+                for M in range(2):
+                    if sec[M] not in alreadydone:
+                        createcubes(sec[M])
+                        createsquares(sec[M])
+                        alreadydone.add(sec[M])
+                        
+        N = 0 # Find the first transition with non-zero scale
+        while N < len(scales) and scales[N] <= minimum_scale:
+            N += 1
+        if N < len(scales):
+            scale = scales[N]
+            cubman(["sc","sq%s.cub" % getmo(logfile.etsecs[i][N][0]),"y","before.cub","y",str(scale)])
+            cubman(["sc","sq%s.cub" % getmo(logfile.etsecs[i][N][1]),"y","after.cub","y",str(scale)])
+            created_tmp = False    
+            for j in range(N + 1, len(logfile.etsecs[i])):
+                scale = scales[j]
+                if scale > minimum_scale:
+                    created_tmp = True                    
+                    cubman(["sc","sq%s.cub" % getmo(logfile.etsecs[i][j][0]),"y","tmp.cub","y",str(scale)])
+                    cubman(["a","tmp.cub","y","before.cub","y","tmp2.cub","y"])
+                    output.write("%s tmp2.cub before.cub\n" % syscmd[MOVE])
+                    cubman(["sc","sq%s.cub" % getmo(logfile.etsecs[i][j][1]),"y","tmp.cub","y",str(scale)])
+                    cubman(["a","tmp.cub","y","after.cub","y","tmp2.cub","y"])
+                    output.write("%s tmp2.cub after.cub\n" % syscmd[MOVE])
+            if created_tmp:
+                output.write("%s tmp.cub\n" % syscmd[DELETE])
+            cubman(["su","before.cub","y","after.cub","y",
+                    "trans%d.cub" % (i+1,),"y"])
+        else:
+            output.write("echo No significant contributions found")
         if windows:
             output.write("goto :end\n")
         else:
